tsseg.algorithms.tglad package
==============================

Compares successive Graphical Lasso precision matrices on sliding windows (Frobenius
distance).

| **Type:** change point detection
| **Supervision:** unsupervised
| **Requires:** PyTorch and networkx

**Implementation:** Wraps vendored uGLAD solver. uGLAD Non-Commercial License.

**Reference:** Shrivastava et al. (2022).

Submodules
----------

tsseg.algorithms.tglad.detector module
--------------------------------------

.. automodule:: tsseg.algorithms.tglad.detector
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.tglad
   :members:
   :show-inheritance:
   :undoc-members:
